@@ -12,11 +12,11 @@ HTML::Truncate - (beta software) truncate HTML by percentage or character count
 
 =head1 VERSION
 
-0.09
+0.10
 
 =cut
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 =head1 ABSTRACT
 
@@ -456,14 +456,59 @@ sub style {
 }
 
 
+=head1 COOKBOOK (well, A recipe)
+
+=head2 Template Toolkit filter
+
+For excerpting HTML in your Templates. Note the C<add_skip_tags> which
+is set to drop any images from the truncated output.
+
+ use Template;
+ use HTML::Truncate;
+
+ my %config =
+    (
+     FILTERS => {
+         truncate_html => [ \&truncate_html_filter_factory, 1 ],
+     },
+     );
+
+ my $tt = Template->new(\%config) or die $Template::ERROR;
+
+ # ... etc ...
+
+ sub truncate_html_filter_factory {
+     my ( $context, $len, $ellipsis ) = @_;
+     $len = 32 unless $len;
+     $ellipsis = chr(8230) unless defined $ellipsis;
+     my $html = shift || return '';
+     my $ht = HTML::Truncate->new();
+     return sub {
+         $ht->add_skip_tags(qw( img ));
+         return $ht->truncate( $html, $len, $ellipsis );
+     }
+ }
+
+Then in your templates you can do things like this:
+
+
+ [% FOR item IN search_results %]
+ <div class="searchResult">
+ <a href="[% item.uri %]">[% item.title %]</a><br />
+ [% item.body | truncate_html(200) %]
+ </div>
+ [% END %]
+
+
+See also L<Template::Filters>.
+
 =head1 TO DO
 
 Many more tests. Allow new stand alone tags to be added. Go through
 entire dist and make sure everything is kosher (autogenerated with the
 lovely L<Module::Starter>). Reorganize POD to read in best learning
 order. Make sure the padding check is working across wide range of
-cases. POD to describe various ways to use it including a TT2 filter.
-"html" style truncating.
+cases. "html" style truncating (maybe not?).
 
 =head1 AUTHOR
 
